@@ -1,4 +1,4 @@
-/* Copyright 2012,2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2012,2014,2015 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**                graph matching functions.               **/
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 01 oct 2012     **/
-/**                                 to     04 jun 2014     **/
+/**                                 to     14 aug 2015     **/
 /**                                                        **/
 /**   NOTES      : # This code partly derives from the     **/
 /**                  code of graph_match.c partly updated  **/
@@ -71,8 +71,8 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
 {
   GraphCoarsenData * restrict const coarptr = (GraphCoarsenData *) (thrdptr->thrddat.grouptr);
   const Graph * restrict const      finegrafptr = coarptr->finegrafptr;
-  Gnum                              finevertnum=0;  /* Current vertex index        */
-  /*Gnum                              finevertnnd;*/  /* Current end of vertex array */
+  Gnum                              finevertnum;  /* Current vertex index        */
+  Gnum                              finevertnnd;  /* Current end of vertex array */
 #ifdef GRAPHMATCHSCANVELOTAB
   Gnum                    finevelomin = (1 * finegrafptr->velosum) / (4 * finegrafptr->vertnbr); /* Minimum load of neighbor */
   Gnum                    coarvelomax = (4 * finegrafptr->velosum) / (1 * (coarptr->coarvertmax - coarptr->finevfixnbr)) + 1;
@@ -85,15 +85,10 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
   Gnum                    pertnbr;
   Gunum                   randval = thrdptr->randval; /* Unsigned to avoid negative random numbers */
 #endif /* ((defined GRAPHMATCHSCANP1INPERT) || defined (GRAPHMATCHSCANP2INPERT)) */
-#if (defined GRAPHMATCHSCANP1INQUEUE || defined GRAPHMATCHSCANP2INQUEUE || defined GRAPHMATCHSCANP1OUTQUEUE || defined GRAPHMATCHSCANP2OUTQUEUE)
+#if ((defined GRAPHMATCHSCANP1INQUEUE) || defined (GRAPHMATCHSCANP2INQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE))
   Gnum * const            queutab = coarptr->finequeutab;
-#endif /* (defined GRAPHMATCHSCANP1INQUEUE || defined GRAPHMATCHSCANP2INQUEUE || defined GRAPHMATCHSCANP1OUTQUEUE || defined GRAPHMATCHSCANP2OUTQUEUE) */
-
-/*#if ((defined GRAPHMATCHSCANP1INQUEUE) || defined (GRAPHMATCHSCANP2INQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE))*/
-#if (defined (GRAPHMATCHSCANP2OUTQUEUE))
   volatile int * const    locktax = coarptr->finelocktax;
-/*#endif *//* ((defined GRAPHMATCHSCANP1INQUEUE) || defined (GRAPHMATCHSCANP2INQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE)) */
-#endif /* (defined (GRAPHMATCHSCANP2OUTQUEUE)) */
+#endif /* ((defined GRAPHMATCHSCANP1INQUEUE) || defined (GRAPHMATCHSCANP2INQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE)) */
 #if ((defined GRAPHMATCHSCANP1INQUEUE) || defined (GRAPHMATCHSCANP2INQUEUE))
   Gnum                    queunnd;
   Gnum                    queunum;
@@ -101,6 +96,7 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
 #if ((defined GRAPHMATCHSCANP1OUTQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE))
   Gnum                    queunew;
 #endif /* ((defined GRAPHMATCHSCANP1OUTQUEUE) || defined (GRAPHMATCHSCANP2OUTQUEUE)) */
+  const int               flagval = coarptr->flagval;
 
   const Gnum * restrict const     fineverttax = finegrafptr->verttax;
   const Gnum * restrict const     finevendtax = finegrafptr->vendtax;
@@ -117,8 +113,8 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
   const Gnum * restrict const     finepfixtax = coarptr->finepfixtax;
 #endif /* GRAPHMATCHSCANPFIXTAB */
 
-/*#ifdef GRAPHMATCHSCANP1INPERT*/                     /* First pass is only for start or sequential routines */
-/*#ifdef GRAPHMATCHSCANVELOTAB*/
+#ifdef GRAPHMATCHSCANP1INPERT                     /* First pass is only for start or sequential routines */
+#ifdef GRAPHMATCHSCANVELOTAB
 #ifdef GRAPHMATCHSCANP1OUTQUEUE
   queunew = thrdptr->queubas;
 #endif /* GRAPHMATCHSCANP1OUTQUEUE */
@@ -154,7 +150,6 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
 
     finevertbst = finevertnum;                    /* Assume we match with ourselves */
 
-#ifdef GRAPHMATCHSCANVELOTAB
     if ((finevelotax[finevertnum] >= finevelomin) || /* If vertex is not too light, skip it and record it  */
         (fineverttax[finevertnum] == finevendtax[finevertnum])) /* Same for isolated vertex: process later */
 #ifdef GRAPHMATCHSCANP1OUTQUEUE
@@ -162,7 +157,6 @@ GraphCoarsenThread * restrict thrdptr)            /* Thread-dependent data */
 #else /* GRAPHMATCHSCANP1OUTQUEUE */
       goto loop1;
 #endif /* GRAPHMATCHSCANP1OUTQUEUE */
-#endif /* GRAPHMATCHSCANVELOTAB */
 
     for (fineedgenum = fineverttax[finevertnum];
          fineedgenum < finevendtax[finevertnum]; fineedgenum ++) {
@@ -222,8 +216,8 @@ loop1: ;
 #ifdef GRAPHMATCHSCANP1OUTQUEUE
   thrdptr->queunnd = queunew;                     /* Record queue index for next pass */
 #endif /* GRAPHMATCHSCANP1OUTQUEUE */
-/*#endif*/ /* GRAPHMATCHSCANVELOTAB    */
-/*#endif*/ /* GRAPHMATCHSCANP1INPERT   */
+#endif /* GRAPHMATCHSCANVELOTAB    */
+#endif /* GRAPHMATCHSCANP1INPERT   */
 
 #ifdef GRAPHMATCHSCANP2OUTQUEUE
   queunew = thrdptr->finequeubas;
@@ -249,13 +243,14 @@ loop1: ;
       finevertnum = pertbas + pertval;            /* Compute corresponding vertex number  */
 #endif /* GRAPHMATCHSCANP2INPERT */
   {
-/*    Gnum                fineedgenum;*/
+    Gnum                fineedgenum;
     Gnum                finevertbst;
 
     if (finematetax[finevertnum] >= 0)            /* If vertex already mated, skip it without remembering it */
       goto loop2;
 
-    if (fineverttax[finevertnum] == finevendtax[finevertnum]) { /* If isolated vertex */
+    if (((flagval & GRAPHCOARSENNOMERGE) == 0) && /* If merging isolated vertices is allowed */
+        (fineverttax[finevertnum] == finevendtax[finevertnum])) { /* And if isolated vertex  */
 #ifdef GRAPHMATCHSCANP2INPERT
       Gnum                perttmp = pertnnd;
       do
