@@ -1,4 +1,4 @@
-/* Copyright 2009-2011,2013-2015 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2009-2011,2013-2016,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**                array.                                  **/
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 05 jan 2009     **/
-/**                                 to   : 01 mar 2015     **/
+/**                                 to   : 28 apr 2019     **/
 /**                                                        **/
 /**   NOTES      : # This code derives from the code of    **/
 /**                  kdgraph_band.c in version 5.2 for     **/
@@ -109,7 +109,6 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
   Gnum                      bandedlonbr;          /* Size of local band edge load array                                                     */
   Gnum                      bandedlosum;
   Gnum * restrict           bandcompload;
-  /*Gnum                      bandcommload;*/
   Gnum * restrict         compload;               /* Load of parts in original graph                                                        */
   Gnum                    fronnum;
   Anum                    domnnbr;
@@ -146,7 +145,6 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
   termhashtab = NULL;
   bandanlotab = NULL;
   bandeeextab = NULL;
-  termhashmsk = 0;
   if (pfixtax != NULL) {                          /* Fixed vertices may be neighbors of band graph vertices and may not belong to the band graph */
     Anum                termhashsiz;
 
@@ -186,7 +184,6 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
           if (termhashtab[termhashnum].termnum == termnum) { /* If hash slot found */
             errorPrint ("kgraphBand: duplicate terminal domain in domain array");
             memFree    (termhashtab);
-            kgraphExit (bandgrafptr);
             return     (1);
           }
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
@@ -229,14 +226,20 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
     errorPrint ("kgraphBand: out of memory (2)");
     return     (1);
   }
+  bandgrafptr->s.verttax -= bandgrafptr->s.baseval;
+  bandgrafptr->s.velotax -= bandgrafptr->s.baseval;
+
   if ((bandvnumtax = memAlloc ((bandvertnbr) * sizeof (Gnum))) == NULL) { /* Allocate alone since it is an output */
     errorPrint ("kgraphBand: out of memory (3)");
+    kgraphExit (bandgrafptr);
     return     (1);
   }
   bandvmlotax = NULL;
   if (vmlotax != NULL) {
     if ((bandvmlotax = memAlloc (bandvertnbr * sizeof (Gnum))) == NULL) {
       errorPrint ("kgraphBand: out of memory (4)");
+      kgraphExit (bandgrafptr);
+      memFree    (bandvnumtax);
       return     (1);
     }
     memSet (bandvnumtax + bandvertnbr - domnnbr, ~0, domnnbr * sizeof (Gnum)); /* Prevent Valgrind from yelling when centralizing band graphs */
@@ -248,22 +251,25 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
   if (parotax != NULL) {
     if ((bandparotax = memAlloc (bandvertnbr * sizeof (Gnum))) == NULL) {
       errorPrint ("kgraphBand: out of memory (5)");
+      if (bandvmlotax != NULL)
+        memFree (bandvmlotax + bandgrafptr->s.baseval);
+      kgraphExit (bandgrafptr);
+      memFree    (bandvnumtax);
       return     (1);
     }
     memSet (bandparotax + bandvertnbr - bandgrafptr->r.m.domnnbr, ~0, bandgrafptr->r.m.domnnbr * sizeof (Gnum)); /* Prevent Valgrind from yelling when centralizing band graphs */
     bandparotax -= bandgrafptr->s.baseval;
-    bandgrafptr->r.m.parttax = bandparotax;
+    bandgrafptr->r.m.parttax  = bandparotax;
     bandgrafptr->r.m.flagval |= MAPPINGFREEPART;
   }
 
-  bandgrafptr->s.verttax -= bandgrafptr->s.baseval;
-  bandvnumtax            -= bandgrafptr->s.baseval;
-  bandgrafptr->s.velotax -= bandgrafptr->s.baseval;
-
   if ((bandgrafptr->s.edgetax = memAlloc ((bandedgenbr + bandedlonbr) * sizeof (Gnum))) == NULL) {
     errorPrint ("kgraphBand: out of memory (6)");
+    kgraphExit (bandgrafptr);
+    memFree    (bandvnumtax);
     return     (1);
   }
+  bandvnumtax            -= bandgrafptr->s.baseval;
   bandedlotax             = NULL;
   bandedgetax             =
   bandgrafptr->s.edgetax -= bandgrafptr->s.baseval;
@@ -337,7 +343,6 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
   bandverttax  = bandgrafptr->s.verttax;
   bandvelotax  = bandgrafptr->s.velotax;
   banddegrmax  = 0;
-  /*bandcommload = 0;*/
   bandcompload = bandgrafptr->comploaddlt;        /* TRICK: use delta array to compute load sums */
   memSet (bandcompload, 0, domnnbr * sizeof (Gnum));
   bandedlosum = 0;
@@ -638,9 +643,7 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
     for (bandvertnum = bandvertlvlnum; bandvertnum < bandvertnnd; /* We do not have fixed vertices */
          bandvertnum ++) {                        /* Link anchors to vertices of last level        */
       Anum              partval;
-      /*Gnum              vertnum;*/
 
-      /*vertnum = bandvnumtax[bandvertnum];*/
       partval = bandparttax[bandvertnum];
       bandedgetax[bandedgetab[partval] ++] = bandvertnum;
 
@@ -692,4 +695,3 @@ Gnum * restrict * restrict const  bandvnumptr)    /*+ Pointer to bandvnumtax
 
   return (0);
 }
-
